==========================================================
 Virtual Transport Interface - kombu.transport.virtual
==========================================================

.. contents::
    :local:
.. currentmodule:: kombu.transport.virtual

.. automodule:: kombu.transport.virtual
    :members:
    :undoc-members:
